Contributing
============

Pull Requests welcome

Authors
=======

- `Jim Rollenhagen <https://github.com/jimrollenhagen>`__
- `Albert Wang <https://github.com/albertyw>`__
- `Daniel Sarfati <https://github.com/fatisar>`__
- `ZeroCater <https://github.com/zerocater>`__
